@@ -28,27 +28,24 @@
 
 #include "fs-interfaces.h"
 
-#include <gst/gst.h>
-
-GST_DEBUG_CATEGORY_EXTERN (fs_base_conference_debug);
-#define GST_CAT_DEFAULT fs_base_conference_debug
-
 #ifdef G_OS_UNIX
 
+#include <arpa/inet.h>
+#include <errno.h>
+#include <net/if.h>
+#include <net/if_arp.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <string.h>
-#include <errno.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
+#include <unistd.h>
 #ifdef HAVE_GETIFADDRS
  #include <sys/socket.h>
  #include <ifaddrs.h>
 #endif
-#include <net/if.h>
-#include <net/if_arp.h>
-#include <arpa/inet.h>
+
+#include <gst/gst.h>
 
 /**
  * SECTION:fs-interfaces
@@ -59,6 +56,10 @@ GST_DEBUG_CATEGORY_EXTERN (fs_base_conference_debug);
  * the address allocated to a network interface.
  */
 
+GST_DEBUG_CATEGORY_EXTERN (fs_base_conference_debug);
+#define GST_CAT_DEFAULT fs_base_conference_debug
+
+
 /**
  * fs_interfaces_get_local_interfaces:
  *
@@ -325,8 +326,11 @@ fs_interfaces_get_local_ips (gboolean include_loopback)
 gchar *
 fs_interfaces_get_ip_for_interface (gchar *interface_name)
 {
+  union  {
+    struct sockaddr  s_addr;
+    struct sockaddr_in sin_addr;
+  } sockaddr_union;
   struct ifreq ifr;
-  struct sockaddr_in *sa;
   gint sockfd;
 
 
@@ -347,9 +351,10 @@ fs_interfaces_get_ip_for_interface (gchar *interface_name)
   }
 
   close (sockfd);
-  sa = (struct sockaddr_in *) &ifr.ifr_addr;
-  GST_DEBUG ("Address for %s: %s", interface_name, inet_ntoa (sa->sin_addr));
-  return g_strdup (inet_ntoa (sa->sin_addr));
+  sockaddr_union.s_addr = ifr.ifr_addr;
+  GST_DEBUG ("Address for %s: %s", interface_name,
+      inet_ntoa (sockaddr_union.sin_addr.sin_addr));
+  return g_strdup (inet_ntoa (sockaddr_union.sin_addr.sin_addr));
 }
 
 #else /* G_OS_UNIX */
