@@ -82,7 +82,7 @@
 #include "fs-conference-iface.h"
 #include "fs-codec.h"
 #include "fs-marshal.h"
-#include "fs-enum-types.h"
+#include "fs-enumtypes.h"
 #include "fs-private.h"
 
 #define GST_CAT_DEFAULT fs_base_conference_debug
