@@ -362,8 +362,10 @@ fs_rtp_special_sources_negotiation_filter (GList *codec_associations)
  *
  * This function removes any special source that are not compatible with the
  * currently selected send codec.
+ *
+ * Returns: %TRUE if a source was removed
  */
-void
+gboolean
 fs_rtp_special_sources_remove (
     GList **extra_sources,
     GList **negotiated_codec_associations,
@@ -371,6 +373,7 @@ fs_rtp_special_sources_remove (
     FsCodec *send_codec)
 {
   GList *klass_item = NULL;
+  gboolean changed = FALSE;
 
   fs_rtp_special_sources_init ();
 
@@ -403,6 +406,7 @@ fs_rtp_special_sources_remove (
       if (!telephony_codec || !fs_codec_are_equal (telephony_codec, obj->codec))
       {
         *extra_sources = g_list_remove (*extra_sources, obj);
+        changed = TRUE;
         g_mutex_unlock (mutex);
         g_object_unref (obj);
         goto restart;
@@ -411,6 +415,8 @@ fs_rtp_special_sources_remove (
 
     g_mutex_unlock (mutex);
   }
+
+  return changed;
 }
 
 static gboolean
@@ -434,8 +440,10 @@ _source_order_compare_func (gconstpointer item1,gconstpointer item2)
  * @rtpmuxer: The rtpmux element
  *
  * This function add special sources that don't already exist but are needed
+ *
+ * Returns: %TRUE if at least one source was added
  */
-void
+gboolean
 fs_rtp_special_sources_create (
     GList **extra_sources,
     GList **negotiated_codec_associations,
@@ -445,6 +453,7 @@ fs_rtp_special_sources_create (
     GstElement *rtpmuxer)
 {
   GList *klass_item = NULL;
+  gboolean changed = FALSE;
 
   fs_rtp_special_sources_init ();
 
@@ -478,7 +487,7 @@ fs_rtp_special_sources_create (
       if (!obj)
       {
         GST_WARNING ("Failed to make new special source");
-        return;
+        return changed;
       }
 
       g_mutex_lock (mutex);
@@ -499,11 +508,14 @@ fs_rtp_special_sources_create (
       {
         *extra_sources = g_list_insert_sorted (*extra_sources,
             obj, _source_order_compare_func);
+        changed = TRUE;
       }
     }
   }
 
   g_mutex_unlock (mutex);
+
+  return changed;
 }
 
 static FsRtpSpecialSource *
@@ -547,7 +559,10 @@ fs_rtp_special_source_new (FsRtpSpecialSourceClass *klass,
   }
 
   source->priv->muxer_request_pad = gst_element_get_request_pad (rtpmuxer,
-      "sink_%d");
+      "priority_sink_%d");
+  if (!source->priv->muxer_request_pad)
+    source->priv->muxer_request_pad = gst_element_get_request_pad (rtpmuxer,
+        "sink_%d");
 
   if (!source->priv->muxer_request_pad)
   {
@@ -765,3 +780,37 @@ fs_rtp_special_source_class_get_codec (FsRtpSpecialSourceClass *klass,
 
   return NULL;
 }
+
+/**
+ * fs_rtp_special_sources_get_codecs_locked:
+ * @special_sources: The #GList of special sources
+ * @codec_associations: The #GList of current codec associations
+ *
+ * Gets the list of the codecs that are used by special sources, excluding
+ * the main codec
+ *
+ * Returns: a #GList of #FsCodec
+ */
+
+GList *
+fs_rtp_special_sources_get_codecs_locked (GList *special_sources,
+    GList *codec_associations, FsCodec *main_codec)
+{
+  GList *result = NULL;
+
+  for (; special_sources; special_sources = special_sources->next)
+  {
+    FsRtpSpecialSource *source = special_sources->data;
+
+    if (main_codec->id != source->codec->id)
+    {
+      CodecAssociation *ca =
+        lookup_codec_association_by_pt (codec_associations, source->codec->id);
+      result = g_list_prepend (result, fs_codec_copy (ca->codec));
+    }
+  }
+
+  result = g_list_reverse (result);
+
+  return result;
+}
