@@ -54,6 +54,10 @@ gint max_buffer_count = 20;
 
 guint max_src_pads = 1;
 
+GStaticMutex testlock = G_STATIC_MUTEX_INIT;
+
+#define TEST_LOCK()   g_static_mutex_lock (&testlock)
+#define TEST_UNLOCK() g_static_mutex_unlock (&testlock)
 
 
 GST_START_TEST (test_rtpconference_new)
@@ -62,7 +66,7 @@ GST_START_TEST (test_rtpconference_new)
   struct SimpleTestStream *st = NULL;
   guint id = 999;
   GList *codecs = NULL;
-  FsMediaType *media_type;
+  FsMediaType media_type;
   GstPad *sinkpad = NULL;
   gchar *str = NULL;
   GstElement *conf = NULL;
@@ -821,6 +825,8 @@ nway_test (int in_count, extra_init extrainit, const gchar *transmitter,
           G_CALLBACK (_negotiated_codecs_notify), dats[i]);
   }
 
+  TEST_LOCK ();
+
   for (i = 0; i < count; i++)
     for (j = 0; j < count; j++)
       if (i != j)
@@ -843,6 +849,8 @@ nway_test (int in_count, extra_init extrainit, const gchar *transmitter,
     set_initial_codecs (dats[0], st);
   }
 
+  TEST_UNLOCK ();
+
   g_main_loop_run (loop);
 
   for (i = 0; i < count; i++)
@@ -868,9 +876,7 @@ GST_END_TEST;
 
 GST_START_TEST (test_rtpconference_three_way)
 {
-  max_src_pads = 2;
   nway_test (3, NULL, "rawudp", 0, NULL);
-  max_src_pads = 1;
 }
 GST_END_TEST;
 
@@ -1066,6 +1072,8 @@ GST_START_TEST (test_rtpconference_no_rtcp)
 }
 GST_END_TEST;
 
+/* Disabled because somehow broken */
+
 #if 0
 static void
 associate_cnames_init (void)
@@ -1088,8 +1096,6 @@ GST_START_TEST (test_rtpconference_three_way_cname_assoc)
 {
   GParameter param = {0};
 
-  return;
-
   param.name = "associate-on-source";
   g_value_init (&param.value, G_TYPE_BOOLEAN);
   g_value_set_boolean (&param.value, FALSE);
@@ -1429,11 +1435,15 @@ min_timeout (TCase *tc_chain, guint min)
 static void unref_session_on_src_pad_added (FsStream *stream,
     GstPad *pad, FsCodec *codec, struct SimpleTestStream *st)
 {
+  TEST_LOCK ();
+
   g_object_unref (st->dat->session);
   st->dat->session = NULL;
   g_object_unref (st->stream);
   st->stream = NULL;
 
+  TEST_UNLOCK ();
+
   g_main_loop_quit (loop);
 }
 
@@ -1485,6 +1495,8 @@ unref_stream_sync_handler (GstBus *bus, GstMessage *message,
   ts_fail_unless (G_VALUE_HOLDS (v, FS_TYPE_STREAM));
   stream = g_value_get_object (v);
 
+  TEST_LOCK ();
+
   for (item = dat->streams; item; item = item->next)
   {
     struct SimpleTestStream *st = item->data;
@@ -1498,6 +1510,8 @@ unref_stream_sync_handler (GstBus *bus, GstMessage *message,
     }
   }
 
+  TEST_UNLOCK ();
+
   gst_message_unref (message);
   return GST_BUS_DROP;
 }
