@@ -46,8 +46,6 @@
 #include <string.h>
 #include <sys/types.h>
 
-#include <udp-bsd.h>
-
 #define GST_CAT_DEFAULT fs_nice_transmitter_debug
 
 /* Signals */
@@ -1484,6 +1482,10 @@ agent_state_changed (NiceAgent *agent,
   data->fs_state = fs_state;
   fs_nice_agent_add_idle (self->priv->agent, state_changed_signal_idle,
       data, free_state_changed_signal_data);
+
+  if (state == NICE_COMPONENT_STATE_READY)
+    fs_nice_transmitter_request_keyunit (self->priv->transmitter,
+        self->priv->gststream, component_id);
 }
 
 
